@@ -22,7 +22,7 @@ Implementation Notes
 import struct
 import time
 
-__version__ = "3.0.6"
+__version__ = "3.0.7"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_NTP.git"
 
 NTP_TO_UNIX_EPOCH = 2208988800  # 1970-01-01 00:00:00
@@ -67,7 +67,9 @@ class NTP:
 
     @property
     def datetime(self) -> time.struct_time:
-        """Current time from NTP server."""
+        """Current time from NTP server. Accessing this property causes the NTP time request,
+        unless there has already been a recent request. Raises OSError exception if no response
+        is received within socket_timeout seconds"""
         if time.monotonic_ns() > self.next_sync:
             self._packet[0] = 0b00100011  # Not leap second, NTP version 4, Client mode
             for i in range(1, len(self._packet)):
